![alt text](docs/Logo.png)

Math right at your finger-tips.

## Usage

![screenshot](docs/screenshot.png)

**Parsers**:

- `basic_parser`: A basic parser that can parse basic math expressions.
- `number_parser`: A parser that can parse numbers.
- `operator_parser`: A parser that can parse operators.

## [Documentation](https://milesianpy-docs.com/)

## Installation

```bash
pip install milesianpy
```

## Development

### Setup

For first time setup:

```bash
make setup
```

> To build, publish, and clean the artifacts in one simple step, run:
> `make all`

### Building

To build the package, run:

```bash
make build
```

### Publishing

To publish the package to pypi, run:

```bash
make publish
```
